﻿using Keyoti.SearchEngine.Index;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Mvc;

namespace DocumentMetaIndexing.Controllers
{
    public class SearchIndexController : Controller
    {
        // GET: SearchIndex
        public ActionResult Index()
        {
            string appURL = string.Format("{0}://{1}{2}", Request.Url.Scheme, Request.Url.Authority, Url.Content("~"));
            
            
            /* NOTE this sample depends upon external URLs, please double check the URLs are accessible before attempting to index them. */

            //Create some meta data that we want to index - typically this would come from a database.
            var documentsToIndex = new List<DocumentMetaData>();
            documentsToIndex.Add(new DocumentMetaData { 
                Author = "Crowd", 
                Url = "https://en.wikipedia.org/wiki/John_Smith", 
                Type = "Web page", 
                Description="Wikipedia page about John Smith", 
                Title="Wikipedia article about John Smith" });

            documentsToIndex.Add(new DocumentMetaData { 
                Author = "Unknown Author", 
                Url = appURL+"/docs/1.pdf", 
                Type = "PDF", 
                Description="PDF about the explorer, John Smith",
                Title="PDF about John Smith" });


            //Create a configuration object using the index directory path where we want to store the index files.
            var config = new Keyoti.SearchEngine.Configuration{IndexDirectory = System.Web.Hosting.HostingEnvironment.MapPath("~/App_Data/Index" )};

            //Force the documents to be reindexed even if they haven't changed, just for testing.
            config.IgnoreLastModifiedDate = true;
            config.UseFileSizeToIdentifyChange = false;


            DocumentIndex documentIndex = null;
            try { 
                documentIndex = new DocumentIndex(config);

                
                
                //Iterate our meta data, and index the documents
                foreach(DocumentMetaData dm in documentsToIndex){
                    var doc = new Keyoti.SearchEngine.Documents.Document(dm.Url, config);

                    var dt = doc.ReadText();
                    //Add our meta data to the indexed content
                    dt.AppendText(dm.Author+" ", config);
                    dt.AppendText(dm.Description+" ", config);
                    doc.Title = dm.Title;

                    //Add extra data to the CustomData so we can use it as the results are generated
                    doc.CustomData="Title="+dm.Title+"&Type="+dm.Type;

                    documentIndex.AddDocument(doc);

                }


            } finally
            {
                if(documentIndex!=null)
                    documentIndex.Close();
            }


            return View();
        }



    }

    class DocumentMetaData
    {
        public string Author { get; set; }
        public string Url { get; set; }
        public string Type { get; set; }
        public string Description { get; set; }
        public string Title { get; set; }

    }
}